@@ -26,11 +26,12 @@ Silicon Motion shall not be used in advertising or otherwise to promote the
 sale, use or other dealings in this Software without prior written
 authorization from the XFree86 Project and Silicon Motion.
 */
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/siliconmotion/smi.h,v 1.12tsi Exp $ */
 
 #ifndef _SMI_H
 #define _SMI_H
 
+#include "smi_pcirename.h"
+
 #include <string.h>
 #include <stdio.h>
 
@@ -187,7 +188,9 @@ typedef struct
     Bool		useEXA;	/* enable exa acceleration */
 
     pciVideoPtr		PciInfo;	/* PCI info vars */
+#ifndef XSERVER_LIBPCIACCESS
     PCITAG		PciTag;
+#endif
     int			Chipset;	/* Chip info, set using PCI
 					   above */
     int			ChipRev;
